@@ -49,7 +49,6 @@ from dashboard_app.models import (
     BundleStream,
     DataReport,
     DataView,
-    ImageHealth,
     Tag,
     Test,
     TestResult,
@@ -165,8 +164,8 @@ class BundleTable(DataTablesTable):
         '<code>{{ record.content_filename }}</code></a>',
         verbose_name="bundle name")
 
-    passes = TemplateColumn('{{ record.get_summary_results.pass }}')
-    fails = TemplateColumn('{{ record.get_summary_results.pass }}')
+    passes = TemplateColumn('{{ record.get_summary_results.pass|default:"0" }}')
+    fails = TemplateColumn('{{ record.get_summary_results.fail|default:"0" }}')
     total_results = TemplateColumn('{{ record.get_summary_results.total }}')
 
     uploaded_on = TemplateColumn('{{ record.uploaded_on|date:"Y-m-d H:i:s"}}')
@@ -347,7 +346,7 @@ class TestRunTable(DataTablesTable):
                 "analyzer_assigned_date",  # used by the view
                 "bundle__uploaded_on",  # needed by Bundle.get_absolute_url
                 "bundle__content_sha1",   # needed by Bundle.get_absolute_url
-                "bundle__bundle_stream__pathname",  # Needed by TestRun.get_absolute_url 
+                "bundle__bundle_stream__pathname",  # Needed by TestRun.get_absolute_url
                 "test__name",  # needed by Test.__unicode__
                 "test__test_id",  # needed by Test.__unicode__
             )
@@ -554,7 +553,7 @@ def attachment_list(request, pathname, content_sha1, analyzer_assigned_uuid):
         template_object_name="attachment",
         extra_context={
             'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                attachment_list, 
+                attachment_list,
                 pathname=pathname,
                 content_sha1=content_sha1,
                 analyzer_assigned_uuid=analyzer_assigned_uuid),
@@ -647,14 +646,14 @@ def data_view_detail(request, name):
     try:
         data_view = DataView.repository.get(name=name)
     except DataView.DoesNotExist:
-        raise Http404('No data view matches the given query.') 
+        raise Http404('No data view matches the given query.')
     return render_to_response(
         "dashboard_app/data_view_detail.html", {
             'bread_crumb_trail': BreadCrumbTrail.leading_to(
                 data_view_detail,
                 name=data_view.name,
                 summary=data_view.summary),
-            "data_view": data_view 
+            "data_view": data_view
         }, RequestContext(request))
 
 
@@ -721,55 +720,6 @@ def redirect_to_bundle(request, content_sha1, trailing=''):
     return redirect_to(request, bundle, trailing)
 
 
-@BreadCrumb("Image Status Matrix", parent=index)
-def image_status_list(request):
-    return render_to_response(
-        "dashboard_app/image_status_list.html", {
-            'hwpack_list': ImageHealth.get_hwpack_list(),
-            'rootfs_list': ImageHealth.get_rootfs_list(),
-            'ImageHealth': ImageHealth,
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(image_status_list)
-        }, RequestContext(request))
-
-
-@BreadCrumb(
-    "Image Status for {rootfs_type} + {hwpack_type}",
-    parent=image_status_list,
-    needs=["rootfs_type", "hwpack_type"])
-def image_status_detail(request, rootfs_type, hwpack_type):
-    image_health = ImageHealth(rootfs_type, hwpack_type)
-    return render_to_response(
-        "dashboard_app/image_status_detail.html", {
-            'image_health': image_health,
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                image_status_detail,
-                rootfs_type=rootfs_type,
-                hwpack_type=hwpack_type),
-        }, RequestContext(request))
-
-
-@BreadCrumb(
-    "Test history for {test_id}",
-    parent=image_status_detail,
-    needs=["rootfs_type", "hwpack_type", "test_id"])
-def image_test_history(request, rootfs_type, hwpack_type, test_id):
-    image_health = ImageHealth(rootfs_type, hwpack_type)
-    test = get_object_or_404(Test, test_id=test_id)
-    test_run_list = image_health.get_test_runs().filter(test=test)
-    return render_to_response(
-        "dashboard_app/image_test_history.html", {
-            'test_run_list': test_run_list,
-            'test': test,
-            'image_health': image_health,
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                image_test_history,
-                rootfs_type=rootfs_type,
-                hwpack_type=hwpack_type,
-                test=test,
-                test_id=test_id),
-        }, RequestContext(request))
-
-
 @BreadCrumb("Testing efforts", parent=index)
 def testing_effort_list(request):
     return render_to_response(
@@ -806,7 +756,7 @@ def testing_effort_detail(request, pk):
 
 
 from lava_projects.models import Project
-from lava_projects.views import project_detail 
+from lava_projects.views import project_detail
 from dashboard_app.forms import TestingEffortForm
 
 
@@ -852,7 +802,7 @@ def testing_effort_create(request, project_identifier):
     parent=testing_effort_detail,
     needs=["pk"])
 @login_required
-def testing_effort_update(request, pk): 
+def testing_effort_update(request, pk):
     try:
         effort = TestingEffort.objects.get(pk=pk)
     except TestingEffort.DoesNotExist:
